# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceCachePerformanceArgs',
    'InstanceCachePerformanceArgsDict',
    'InstanceCapacityArgs',
    'InstanceCapacityArgsDict',
    'InstanceTagArgs',
    'InstanceTagArgsDict',
    'MountPointClientArgs',
    'MountPointClientArgsDict',
    'MountPointPermissionGroupArgs',
    'MountPointPermissionGroupArgsDict',
    'MountPointPermissionGroupMountPointArgs',
    'MountPointPermissionGroupMountPointArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceCachePerformanceArgsDict(TypedDict):
        cache_bandwidth: NotRequired[pulumi.Input[builtins.int]]
        """
        预配置带宽，用于增加文件系统带宽。
        """
elif False:
    InstanceCachePerformanceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceCachePerformanceArgs:
    def __init__(__self__, *,
                 cache_bandwidth: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.int] cache_bandwidth: 预配置带宽，用于增加文件系统带宽。
        """
        if cache_bandwidth is not None:
            pulumi.set(__self__, "cache_bandwidth", cache_bandwidth)

    @property
    @pulumi.getter(name="cacheBandwidth")
    def cache_bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        预配置带宽，用于增加文件系统带宽。
        """
        return pulumi.get(self, "cache_bandwidth")

    @cache_bandwidth.setter
    def cache_bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cache_bandwidth", value)


if not MYPY:
    class InstanceCapacityArgsDict(TypedDict):
        total: NotRequired[pulumi.Input[builtins.float]]
        """
        文件系统可用总容量，单位为 GiB。
        """
        used: NotRequired[pulumi.Input[builtins.float]]
        """
        文件系统已使用容量，单位为 MiB。
        """
elif False:
    InstanceCapacityArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceCapacityArgs:
    def __init__(__self__, *,
                 total: Optional[pulumi.Input[builtins.float]] = None,
                 used: Optional[pulumi.Input[builtins.float]] = None):
        """
        :param pulumi.Input[builtins.float] total: 文件系统可用总容量，单位为 GiB。
        :param pulumi.Input[builtins.float] used: 文件系统已使用容量，单位为 MiB。
        """
        if total is not None:
            pulumi.set(__self__, "total", total)
        if used is not None:
            pulumi.set(__self__, "used", used)

    @property
    @pulumi.getter
    def total(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        文件系统可用总容量，单位为 GiB。
        """
        return pulumi.get(self, "total")

    @total.setter
    def total(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "total", value)

    @property
    @pulumi.getter
    def used(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        文件系统已使用容量，单位为 MiB。
        """
        return pulumi.get(self, "used")

    @used.setter
    def used(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "used", value)


if not MYPY:
    class InstanceTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        标签类型。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    InstanceTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] type: 标签类型。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签类型。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class MountPointClientArgsDict(TypedDict):
        ip: NotRequired[pulumi.Input[builtins.str]]
        """
        客户端的私有网络 IP 地址。
        """
        protocol_version: NotRequired[pulumi.Input[builtins.str]]
        """
        挂载协议版本号。取值：NFSv3。
        """
        vpc_name: NotRequired[pulumi.Input[builtins.str]]
        """
        私有网络名称。
        """
elif False:
    MountPointClientArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class MountPointClientArgs:
    def __init__(__self__, *,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 protocol_version: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] ip: 客户端的私有网络 IP 地址。
        :param pulumi.Input[builtins.str] protocol_version: 挂载协议版本号。取值：NFSv3。
        :param pulumi.Input[builtins.str] vpc_name: 私有网络名称。
        """
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if protocol_version is not None:
            pulumi.set(__self__, "protocol_version", protocol_version)
        if vpc_name is not None:
            pulumi.set(__self__, "vpc_name", vpc_name)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        客户端的私有网络 IP 地址。
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="protocolVersion")
    def protocol_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载协议版本号。取值：NFSv3。
        """
        return pulumi.get(self, "protocol_version")

    @protocol_version.setter
    def protocol_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol_version", value)

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络名称。
        """
        return pulumi.get(self, "vpc_name")

    @vpc_name.setter
    def vpc_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_name", value)


if not MYPY:
    class MountPointPermissionGroupArgsDict(TypedDict):
        create_time: NotRequired[pulumi.Input[builtins.str]]
        """
        权限组创建时间。
        """
        description: NotRequired[pulumi.Input[builtins.str]]
        """
        权限组描述信息。
        """
        file_system_count: NotRequired[pulumi.Input[builtins.int]]
        """
        关联该权限组的文件系统数量。
        """
        file_system_type: NotRequired[pulumi.Input[builtins.str]]
        """
        文件系统类型。取值说明如下：Extreme：NAS 极速型。Capacity：NAS 容量型。Cache：NAS 缓存型。
        """
        mount_points: NotRequired[pulumi.Input[Sequence[pulumi.Input['MountPointPermissionGroupMountPointArgsDict']]]]
        permission_group_name: NotRequired[pulumi.Input[builtins.str]]
        """
        权限组名称。
        """
        permission_rule_count: NotRequired[pulumi.Input[builtins.int]]
        """
        权限规则数量。
        """
elif False:
    MountPointPermissionGroupArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class MountPointPermissionGroupArgs:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 file_system_count: Optional[pulumi.Input[builtins.int]] = None,
                 file_system_type: Optional[pulumi.Input[builtins.str]] = None,
                 mount_points: Optional[pulumi.Input[Sequence[pulumi.Input['MountPointPermissionGroupMountPointArgs']]]] = None,
                 permission_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 permission_rule_count: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.str] create_time: 权限组创建时间。
        :param pulumi.Input[builtins.str] description: 权限组描述信息。
        :param pulumi.Input[builtins.int] file_system_count: 关联该权限组的文件系统数量。
        :param pulumi.Input[builtins.str] file_system_type: 文件系统类型。取值说明如下：Extreme：NAS 极速型。Capacity：NAS 容量型。Cache：NAS 缓存型。
        :param pulumi.Input[builtins.str] permission_group_name: 权限组名称。
        :param pulumi.Input[builtins.int] permission_rule_count: 权限规则数量。
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if file_system_count is not None:
            pulumi.set(__self__, "file_system_count", file_system_count)
        if file_system_type is not None:
            pulumi.set(__self__, "file_system_type", file_system_type)
        if mount_points is not None:
            pulumi.set(__self__, "mount_points", mount_points)
        if permission_group_name is not None:
            pulumi.set(__self__, "permission_group_name", permission_group_name)
        if permission_rule_count is not None:
            pulumi.set(__self__, "permission_rule_count", permission_rule_count)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        权限组创建时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        权限组描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="fileSystemCount")
    def file_system_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        关联该权限组的文件系统数量。
        """
        return pulumi.get(self, "file_system_count")

    @file_system_count.setter
    def file_system_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "file_system_count", value)

    @property
    @pulumi.getter(name="fileSystemType")
    def file_system_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统类型。取值说明如下：Extreme：NAS 极速型。Capacity：NAS 容量型。Cache：NAS 缓存型。
        """
        return pulumi.get(self, "file_system_type")

    @file_system_type.setter
    def file_system_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "file_system_type", value)

    @property
    @pulumi.getter(name="mountPoints")
    def mount_points(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MountPointPermissionGroupMountPointArgs']]]]:
        return pulumi.get(self, "mount_points")

    @mount_points.setter
    def mount_points(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MountPointPermissionGroupMountPointArgs']]]]):
        pulumi.set(self, "mount_points", value)

    @property
    @pulumi.getter(name="permissionGroupName")
    def permission_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        权限组名称。
        """
        return pulumi.get(self, "permission_group_name")

    @permission_group_name.setter
    def permission_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission_group_name", value)

    @property
    @pulumi.getter(name="permissionRuleCount")
    def permission_rule_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        权限规则数量。
        """
        return pulumi.get(self, "permission_rule_count")

    @permission_rule_count.setter
    def permission_rule_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "permission_rule_count", value)


if not MYPY:
    class MountPointPermissionGroupMountPointArgsDict(TypedDict):
        file_system_id: NotRequired[pulumi.Input[builtins.str]]
        """
        文件系统 ID。
        """
        mount_point_id: NotRequired[pulumi.Input[builtins.str]]
        """
        挂载点 ID。
        """
        mount_point_name: NotRequired[pulumi.Input[builtins.str]]
        """
        挂载点名称。
        """
elif False:
    MountPointPermissionGroupMountPointArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class MountPointPermissionGroupMountPointArgs:
    def __init__(__self__, *,
                 file_system_id: Optional[pulumi.Input[builtins.str]] = None,
                 mount_point_id: Optional[pulumi.Input[builtins.str]] = None,
                 mount_point_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] file_system_id: 文件系统 ID。
        :param pulumi.Input[builtins.str] mount_point_id: 挂载点 ID。
        :param pulumi.Input[builtins.str] mount_point_name: 挂载点名称。
        """
        if file_system_id is not None:
            pulumi.set(__self__, "file_system_id", file_system_id)
        if mount_point_id is not None:
            pulumi.set(__self__, "mount_point_id", mount_point_id)
        if mount_point_name is not None:
            pulumi.set(__self__, "mount_point_name", mount_point_name)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="mountPointId")
    def mount_point_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点 ID。
        """
        return pulumi.get(self, "mount_point_id")

    @mount_point_id.setter
    def mount_point_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mount_point_id", value)

    @property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点名称。
        """
        return pulumi.get(self, "mount_point_name")

    @mount_point_name.setter
    def mount_point_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mount_point_name", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetIpv6GatewayResult',
    'AwaitableGetIpv6GatewayResult',
    'get_ipv6_gateway',
    'get_ipv6_gateway_output',
]

@pulumi.output_type
class GetIpv6GatewayResult:
    """
    A collection of values returned by getIpv6Gateway.
    """
    def __init__(__self__, created_time=None, description=None, id=None, ipv6_gateway_id=None, name=None, project_name=None, route_table_id=None, status=None, tags=None, updated_time=None, vpc_id=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipv6_gateway_id and not isinstance(ipv6_gateway_id, str):
            raise TypeError("Expected argument 'ipv6_gateway_id' to be a str")
        pulumi.set(__self__, "ipv6_gateway_id", ipv6_gateway_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if route_table_id and not isinstance(route_table_id, str):
            raise TypeError("Expected argument 'route_table_id' to be a str")
        pulumi.set(__self__, "route_table_id", route_table_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        IPv6网关实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        IPv6网关实例的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipv6GatewayId")
    def ipv6_gateway_id(self) -> builtins.str:
        """
        IPv6网关实例的ID。
        """
        return pulumi.get(self, "ipv6_gateway_id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        IPv6网关实例的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为IPv6网关ID。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        IPv6网关所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="routeTableId")
    def route_table_id(self) -> builtins.str:
        """
        IPv6网关实例关联的路由表ID。
        """
        return pulumi.get(self, "route_table_id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        IPv6网关实例的运行状态。取值如下：Creating：创建中。Deleting：删除中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetIpv6GatewayTagResult']:
        """
        标签信息
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        IPv6网关实例的修改时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        需关联IPv6网关实例的VPC ID。每个VPC只能关联一个IPv6网关实例，需确保待关联的VPC未关联其他IPv6网关实例。
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetIpv6GatewayResult(GetIpv6GatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpv6GatewayResult(
            created_time=self.created_time,
            description=self.description,
            id=self.id,
            ipv6_gateway_id=self.ipv6_gateway_id,
            name=self.name,
            project_name=self.project_name,
            route_table_id=self.route_table_id,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time,
            vpc_id=self.vpc_id)


def get_ipv6_gateway(id: Optional[builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpv6GatewayResult:
    """
    Data Source schema for Byteplus::VPC::Ipv6Gateway


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getIpv6Gateway:getIpv6Gateway', __args__, opts=opts, typ=GetIpv6GatewayResult).value

    return AwaitableGetIpv6GatewayResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        ipv6_gateway_id=pulumi.get(__ret__, 'ipv6_gateway_id'),
        name=pulumi.get(__ret__, 'name'),
        project_name=pulumi.get(__ret__, 'project_name'),
        route_table_id=pulumi.get(__ret__, 'route_table_id'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_ipv6_gateway_output(id: Optional[pulumi.Input[builtins.str]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIpv6GatewayResult]:
    """
    Data Source schema for Byteplus::VPC::Ipv6Gateway


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getIpv6Gateway:getIpv6Gateway', __args__, opts=opts, typ=GetIpv6GatewayResult)
    return __ret__.apply(lambda __response__: GetIpv6GatewayResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        ipv6_gateway_id=pulumi.get(__response__, 'ipv6_gateway_id'),
        name=pulumi.get(__response__, 'name'),
        project_name=pulumi.get(__response__, 'project_name'),
        route_table_id=pulumi.get(__response__, 'route_table_id'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TrafficMirrorTargetArgs', 'TrafficMirrorTarget']

@pulumi.input_type
class TrafficMirrorTargetArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[builtins.str],
                 instance_type: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorTargetTagArgs']]]] = None,
                 traffic_mirror_target_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a TrafficMirrorTarget resource.
        :param pulumi.Input[builtins.str] instance_id: 镜像目的的资源ID。
        :param pulumi.Input[builtins.str] instance_type: 镜像目的的资源类型。NetworkInterface：弹性网卡。ClbInstance：传统型负载均衡。
        :param pulumi.Input[builtins.str] description: 监听器的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。不填则默认值为空字符串。
        :param pulumi.Input[builtins.str] project_name: 镜像目的所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.str] traffic_mirror_target_name: 监听器的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线_）和中划线（-）。长度限制在1～128字符之间。不填则默认将“协议-端口”作为监听器名称。
        """
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "instance_type", instance_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if traffic_mirror_target_name is not None:
            pulumi.set(__self__, "traffic_mirror_target_name", traffic_mirror_target_name)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        镜像目的的资源ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Input[builtins.str]:
        """
        镜像目的的资源类型。NetworkInterface：弹性网卡。ClbInstance：传统型负载均衡。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。不填则默认值为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像目的所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorTargetTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorTargetTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="trafficMirrorTargetName")
    def traffic_mirror_target_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线_）和中划线（-）。长度限制在1～128字符之间。不填则默认将“协议-端口”作为监听器名称。
        """
        return pulumi.get(self, "traffic_mirror_target_name")

    @traffic_mirror_target_name.setter
    def traffic_mirror_target_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_mirror_target_name", value)


@pulumi.input_type
class _TrafficMirrorTargetState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorTargetTagArgs']]]] = None,
                 traffic_mirror_target_id: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_target_name: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering TrafficMirrorTarget resources.
        :param pulumi.Input[builtins.str] created_at: 镜像会话的创建时间。
        :param pulumi.Input[builtins.str] description: 监听器的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。不填则默认值为空字符串。
        :param pulumi.Input[builtins.str] instance_id: 镜像目的的资源ID。
        :param pulumi.Input[builtins.str] instance_type: 镜像目的的资源类型。NetworkInterface：弹性网卡。ClbInstance：传统型负载均衡。
        :param pulumi.Input[builtins.str] project_name: 镜像目的所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.str] status: 镜像目的状态。Available：可用。Creating：创建中。
        :param pulumi.Input[builtins.str] traffic_mirror_target_id: 镜像目的的ID。
        :param pulumi.Input[builtins.str] traffic_mirror_target_name: 监听器的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线_）和中划线（-）。长度限制在1～128字符之间。不填则默认将“协议-端口”作为监听器名称。
        :param pulumi.Input[builtins.str] updated_at: 镜像会话的更新时间。
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if traffic_mirror_target_id is not None:
            pulumi.set(__self__, "traffic_mirror_target_id", traffic_mirror_target_id)
        if traffic_mirror_target_name is not None:
            pulumi.set(__self__, "traffic_mirror_target_name", traffic_mirror_target_name)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像会话的创建时间。
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。不填则默认值为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像目的的资源ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像目的的资源类型。NetworkInterface：弹性网卡。ClbInstance：传统型负载均衡。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像目的所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像目的状态。Available：可用。Creating：创建中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorTargetTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorTargetTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="trafficMirrorTargetId")
    def traffic_mirror_target_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像目的的ID。
        """
        return pulumi.get(self, "traffic_mirror_target_id")

    @traffic_mirror_target_id.setter
    def traffic_mirror_target_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_mirror_target_id", value)

    @property
    @pulumi.getter(name="trafficMirrorTargetName")
    def traffic_mirror_target_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线_）和中划线（-）。长度限制在1～128字符之间。不填则默认将“协议-端口”作为监听器名称。
        """
        return pulumi.get(self, "traffic_mirror_target_name")

    @traffic_mirror_target_name.setter
    def traffic_mirror_target_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_mirror_target_name", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像会话的更新时间。
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("bytepluscc:vpc/trafficMirrorTarget:TrafficMirrorTarget")
class TrafficMirrorTarget(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TrafficMirrorTargetTagArgs', 'TrafficMirrorTargetTagArgsDict']]]]] = None,
                 traffic_mirror_target_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        镜像目的是收集流量的网卡或传统型负载均衡。您可以通过流量镜像，按自己设定的筛选条件复制网卡的流量，并将复制的流量私网转发到目标服务进行监控分析。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_traffic_mirror_target_demo = bytepluscc.vpc.TrafficMirrorTarget("VPCTrafficMirrorTargetDemo",
            traffic_mirror_target_name="test-terraformtest",
            description="this is a test",
            instance_id="eni-2yggxh4o692bk6asvxxxxx",
            instance_type="NetworkInterface",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/trafficMirrorTarget:TrafficMirrorTarget example "traffic_mirror_target_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 监听器的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。不填则默认值为空字符串。
        :param pulumi.Input[builtins.str] instance_id: 镜像目的的资源ID。
        :param pulumi.Input[builtins.str] instance_type: 镜像目的的资源类型。NetworkInterface：弹性网卡。ClbInstance：传统型负载均衡。
        :param pulumi.Input[builtins.str] project_name: 镜像目的所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.str] traffic_mirror_target_name: 监听器的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线_）和中划线（-）。长度限制在1～128字符之间。不填则默认将“协议-端口”作为监听器名称。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TrafficMirrorTargetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        镜像目的是收集流量的网卡或传统型负载均衡。您可以通过流量镜像，按自己设定的筛选条件复制网卡的流量，并将复制的流量私网转发到目标服务进行监控分析。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_traffic_mirror_target_demo = bytepluscc.vpc.TrafficMirrorTarget("VPCTrafficMirrorTargetDemo",
            traffic_mirror_target_name="test-terraformtest",
            description="this is a test",
            instance_id="eni-2yggxh4o692bk6asvxxxxx",
            instance_type="NetworkInterface",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/trafficMirrorTarget:TrafficMirrorTarget example "traffic_mirror_target_id"
        ```

        :param str resource_name: The name of the resource.
        :param TrafficMirrorTargetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TrafficMirrorTargetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TrafficMirrorTargetTagArgs', 'TrafficMirrorTargetTagArgsDict']]]]] = None,
                 traffic_mirror_target_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TrafficMirrorTargetArgs.__new__(TrafficMirrorTargetArgs)

            __props__.__dict__["description"] = description
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            if instance_type is None and not opts.urn:
                raise TypeError("Missing required property 'instance_type'")
            __props__.__dict__["instance_type"] = instance_type
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["traffic_mirror_target_name"] = traffic_mirror_target_name
            __props__.__dict__["created_at"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["traffic_mirror_target_id"] = None
            __props__.__dict__["updated_at"] = None
        super(TrafficMirrorTarget, __self__).__init__(
            'bytepluscc:vpc/trafficMirrorTarget:TrafficMirrorTarget',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_type: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TrafficMirrorTargetTagArgs', 'TrafficMirrorTargetTagArgsDict']]]]] = None,
            traffic_mirror_target_id: Optional[pulumi.Input[builtins.str]] = None,
            traffic_mirror_target_name: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'TrafficMirrorTarget':
        """
        Get an existing TrafficMirrorTarget resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_at: 镜像会话的创建时间。
        :param pulumi.Input[builtins.str] description: 监听器的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。不填则默认值为空字符串。
        :param pulumi.Input[builtins.str] instance_id: 镜像目的的资源ID。
        :param pulumi.Input[builtins.str] instance_type: 镜像目的的资源类型。NetworkInterface：弹性网卡。ClbInstance：传统型负载均衡。
        :param pulumi.Input[builtins.str] project_name: 镜像目的所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.str] status: 镜像目的状态。Available：可用。Creating：创建中。
        :param pulumi.Input[builtins.str] traffic_mirror_target_id: 镜像目的的ID。
        :param pulumi.Input[builtins.str] traffic_mirror_target_name: 监听器的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线_）和中划线（-）。长度限制在1～128字符之间。不填则默认将“协议-端口”作为监听器名称。
        :param pulumi.Input[builtins.str] updated_at: 镜像会话的更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TrafficMirrorTargetState.__new__(_TrafficMirrorTargetState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["traffic_mirror_target_id"] = traffic_mirror_target_id
        __props__.__dict__["traffic_mirror_target_name"] = traffic_mirror_target_name
        __props__.__dict__["updated_at"] = updated_at
        return TrafficMirrorTarget(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        镜像会话的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        监听器的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。不填则默认值为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        镜像目的的资源ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[builtins.str]:
        """
        镜像目的的资源类型。NetworkInterface：弹性网卡。ClbInstance：传统型负载均衡。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        镜像目的所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        镜像目的状态。Available：可用。Creating：创建中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.TrafficMirrorTargetTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="trafficMirrorTargetId")
    def traffic_mirror_target_id(self) -> pulumi.Output[builtins.str]:
        """
        镜像目的的ID。
        """
        return pulumi.get(self, "traffic_mirror_target_id")

    @property
    @pulumi.getter(name="trafficMirrorTargetName")
    def traffic_mirror_target_name(self) -> pulumi.Output[builtins.str]:
        """
        监听器的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线_）和中划线（-）。长度限制在1～128字符之间。不填则默认将“协议-端口”作为监听器名称。
        """
        return pulumi.get(self, "traffic_mirror_target_name")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        镜像会话的更新时间。
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAllowListResult',
    'AwaitableGetAllowListResult',
    'get_allow_list',
    'get_allow_list_output',
]

@pulumi.output_type
class GetAllowListResult:
    """
    A collection of values returned by getAllowList.
    """
    def __init__(__self__, allow_list_category=None, allow_list_desc=None, allow_list_id=None, allow_list_ip_num=None, allow_list_name=None, allow_list_type=None, allow_lists=None, associated_instance_num=None, associated_instances=None, id=None, ignore_instance_status=None, instance_id=None, ip_lists=None, modify_mode=None, project_name=None, security_group_bind_infos=None, security_group_ids=None, update_security_group=None, user_allow_lists=None):
        if allow_list_category and not isinstance(allow_list_category, str):
            raise TypeError("Expected argument 'allow_list_category' to be a str")
        pulumi.set(__self__, "allow_list_category", allow_list_category)
        if allow_list_desc and not isinstance(allow_list_desc, str):
            raise TypeError("Expected argument 'allow_list_desc' to be a str")
        pulumi.set(__self__, "allow_list_desc", allow_list_desc)
        if allow_list_id and not isinstance(allow_list_id, str):
            raise TypeError("Expected argument 'allow_list_id' to be a str")
        pulumi.set(__self__, "allow_list_id", allow_list_id)
        if allow_list_ip_num and not isinstance(allow_list_ip_num, int):
            raise TypeError("Expected argument 'allow_list_ip_num' to be a int")
        pulumi.set(__self__, "allow_list_ip_num", allow_list_ip_num)
        if allow_list_name and not isinstance(allow_list_name, str):
            raise TypeError("Expected argument 'allow_list_name' to be a str")
        pulumi.set(__self__, "allow_list_name", allow_list_name)
        if allow_list_type and not isinstance(allow_list_type, str):
            raise TypeError("Expected argument 'allow_list_type' to be a str")
        pulumi.set(__self__, "allow_list_type", allow_list_type)
        if allow_lists and not isinstance(allow_lists, list):
            raise TypeError("Expected argument 'allow_lists' to be a list")
        pulumi.set(__self__, "allow_lists", allow_lists)
        if associated_instance_num and not isinstance(associated_instance_num, int):
            raise TypeError("Expected argument 'associated_instance_num' to be a int")
        pulumi.set(__self__, "associated_instance_num", associated_instance_num)
        if associated_instances and not isinstance(associated_instances, list):
            raise TypeError("Expected argument 'associated_instances' to be a list")
        pulumi.set(__self__, "associated_instances", associated_instances)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ignore_instance_status and not isinstance(ignore_instance_status, bool):
            raise TypeError("Expected argument 'ignore_instance_status' to be a bool")
        pulumi.set(__self__, "ignore_instance_status", ignore_instance_status)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if ip_lists and not isinstance(ip_lists, list):
            raise TypeError("Expected argument 'ip_lists' to be a list")
        pulumi.set(__self__, "ip_lists", ip_lists)
        if modify_mode and not isinstance(modify_mode, str):
            raise TypeError("Expected argument 'modify_mode' to be a str")
        pulumi.set(__self__, "modify_mode", modify_mode)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if security_group_bind_infos and not isinstance(security_group_bind_infos, list):
            raise TypeError("Expected argument 'security_group_bind_infos' to be a list")
        pulumi.set(__self__, "security_group_bind_infos", security_group_bind_infos)
        if security_group_ids and not isinstance(security_group_ids, list):
            raise TypeError("Expected argument 'security_group_ids' to be a list")
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        if update_security_group and not isinstance(update_security_group, bool):
            raise TypeError("Expected argument 'update_security_group' to be a bool")
        pulumi.set(__self__, "update_security_group", update_security_group)
        if user_allow_lists and not isinstance(user_allow_lists, list):
            raise TypeError("Expected argument 'user_allow_lists' to be a list")
        pulumi.set(__self__, "user_allow_lists", user_allow_lists)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> builtins.str:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        """
        return pulumi.get(self, "allow_list_category")

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> builtins.str:
        """
        白名单的备注。
        """
        return pulumi.get(self, "allow_list_desc")

    @property
    @pulumi.getter(name="allowListId")
    def allow_list_id(self) -> builtins.str:
        """
        白名单 ID 。
        """
        return pulumi.get(self, "allow_list_id")

    @property
    @pulumi.getter(name="allowListIpNum")
    def allow_list_ip_num(self) -> builtins.int:
        """
        白名单内的 IP 地址（或地址段）总数。
        """
        return pulumi.get(self, "allow_list_ip_num")

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> builtins.str:
        """
        白名单名称。
        """
        return pulumi.get(self, "allow_list_name")

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> builtins.str:
        """
        白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        """
        return pulumi.get(self, "allow_list_type")

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Sequence[builtins.str]:
        """
        白名单内的 IP 地址列表
        """
        return pulumi.get(self, "allow_lists")

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> builtins.int:
        """
        白名单下绑定的实例总数。
        """
        return pulumi.get(self, "associated_instance_num")

    @property
    @pulumi.getter(name="associatedInstances")
    def associated_instances(self) -> Sequence['outputs.GetAllowListAssociatedInstanceResult']:
        """
        已绑定当前白名单的实例信息。
        """
        return pulumi.get(self, "associated_instances")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ignoreInstanceStatus")
    def ignore_instance_status(self) -> builtins.bool:
        """
        是否忽略实例状态校验。取值：true：是。false：否。默认值。
        """
        return pulumi.get(self, "ignore_instance_status")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="ipLists")
    def ip_lists(self) -> Sequence[builtins.str]:
        """
        白名单包含的 IP 地址和 IP 地址段的列表。在请求参数 WithIpList 取值为 true 时返回，在取值为 false 或不为其传值时返回为 null。
        """
        return pulumi.get(self, "ip_lists")

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> builtins.str:
        """
        修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        """
        return pulumi.get(self, "modify_mode")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> Sequence['outputs.GetAllowListSecurityGroupBindInfoResult']:
        """
        白名单关联的安全组的信息。说明该字段不能与 SecurityGroupIds 同时使用。
        """
        return pulumi.get(self, "security_group_bind_infos")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Sequence[builtins.str]:
        """
        需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> builtins.bool:
        """
        是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        """
        return pulumi.get(self, "update_security_group")

    @property
    @pulumi.getter(name="userAllowLists")
    def user_allow_lists(self) -> Sequence[builtins.str]:
        """
        该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        return pulumi.get(self, "user_allow_lists")


class AwaitableGetAllowListResult(GetAllowListResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAllowListResult(
            allow_list_category=self.allow_list_category,
            allow_list_desc=self.allow_list_desc,
            allow_list_id=self.allow_list_id,
            allow_list_ip_num=self.allow_list_ip_num,
            allow_list_name=self.allow_list_name,
            allow_list_type=self.allow_list_type,
            allow_lists=self.allow_lists,
            associated_instance_num=self.associated_instance_num,
            associated_instances=self.associated_instances,
            id=self.id,
            ignore_instance_status=self.ignore_instance_status,
            instance_id=self.instance_id,
            ip_lists=self.ip_lists,
            modify_mode=self.modify_mode,
            project_name=self.project_name,
            security_group_bind_infos=self.security_group_bind_infos,
            security_group_ids=self.security_group_ids,
            update_security_group=self.update_security_group,
            user_allow_lists=self.user_allow_lists)


def get_allow_list(id: Optional[builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAllowListResult:
    """
    Data Source schema for Byteplus::RDSMySQL::AllowList


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:rdsmysql/getAllowList:getAllowList', __args__, opts=opts, typ=GetAllowListResult).value

    return AwaitableGetAllowListResult(
        allow_list_category=pulumi.get(__ret__, 'allow_list_category'),
        allow_list_desc=pulumi.get(__ret__, 'allow_list_desc'),
        allow_list_id=pulumi.get(__ret__, 'allow_list_id'),
        allow_list_ip_num=pulumi.get(__ret__, 'allow_list_ip_num'),
        allow_list_name=pulumi.get(__ret__, 'allow_list_name'),
        allow_list_type=pulumi.get(__ret__, 'allow_list_type'),
        allow_lists=pulumi.get(__ret__, 'allow_lists'),
        associated_instance_num=pulumi.get(__ret__, 'associated_instance_num'),
        associated_instances=pulumi.get(__ret__, 'associated_instances'),
        id=pulumi.get(__ret__, 'id'),
        ignore_instance_status=pulumi.get(__ret__, 'ignore_instance_status'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        ip_lists=pulumi.get(__ret__, 'ip_lists'),
        modify_mode=pulumi.get(__ret__, 'modify_mode'),
        project_name=pulumi.get(__ret__, 'project_name'),
        security_group_bind_infos=pulumi.get(__ret__, 'security_group_bind_infos'),
        security_group_ids=pulumi.get(__ret__, 'security_group_ids'),
        update_security_group=pulumi.get(__ret__, 'update_security_group'),
        user_allow_lists=pulumi.get(__ret__, 'user_allow_lists'))
def get_allow_list_output(id: Optional[pulumi.Input[builtins.str]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAllowListResult]:
    """
    Data Source schema for Byteplus::RDSMySQL::AllowList


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:rdsmysql/getAllowList:getAllowList', __args__, opts=opts, typ=GetAllowListResult)
    return __ret__.apply(lambda __response__: GetAllowListResult(
        allow_list_category=pulumi.get(__response__, 'allow_list_category'),
        allow_list_desc=pulumi.get(__response__, 'allow_list_desc'),
        allow_list_id=pulumi.get(__response__, 'allow_list_id'),
        allow_list_ip_num=pulumi.get(__response__, 'allow_list_ip_num'),
        allow_list_name=pulumi.get(__response__, 'allow_list_name'),
        allow_list_type=pulumi.get(__response__, 'allow_list_type'),
        allow_lists=pulumi.get(__response__, 'allow_lists'),
        associated_instance_num=pulumi.get(__response__, 'associated_instance_num'),
        associated_instances=pulumi.get(__response__, 'associated_instances'),
        id=pulumi.get(__response__, 'id'),
        ignore_instance_status=pulumi.get(__response__, 'ignore_instance_status'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        ip_lists=pulumi.get(__response__, 'ip_lists'),
        modify_mode=pulumi.get(__response__, 'modify_mode'),
        project_name=pulumi.get(__response__, 'project_name'),
        security_group_bind_infos=pulumi.get(__response__, 'security_group_bind_infos'),
        security_group_ids=pulumi.get(__response__, 'security_group_ids'),
        update_security_group=pulumi.get(__response__, 'update_security_group'),
        user_allow_lists=pulumi.get(__response__, 'user_allow_lists')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNodeResult',
    'AwaitableGetNodeResult',
    'get_node',
    'get_node_output',
]

@pulumi.output_type
class GetNodeResult:
    """
    A collection of values returned by getNode.
    """
    def __init__(__self__, additional_container_storage_enabled=None, cluster_id=None, container_storage_path=None, created_time=None, id=None, image_id=None, initialize_script=None, instance_id=None, is_virtual=None, keep_instance_name=None, kubernetes_config=None, name=None, node_id=None, node_pool_id=None, roles=None, status=None, updated_time=None, zone_id=None):
        if additional_container_storage_enabled and not isinstance(additional_container_storage_enabled, bool):
            raise TypeError("Expected argument 'additional_container_storage_enabled' to be a bool")
        pulumi.set(__self__, "additional_container_storage_enabled", additional_container_storage_enabled)
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if container_storage_path and not isinstance(container_storage_path, str):
            raise TypeError("Expected argument 'container_storage_path' to be a str")
        pulumi.set(__self__, "container_storage_path", container_storage_path)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if initialize_script and not isinstance(initialize_script, str):
            raise TypeError("Expected argument 'initialize_script' to be a str")
        pulumi.set(__self__, "initialize_script", initialize_script)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if is_virtual and not isinstance(is_virtual, bool):
            raise TypeError("Expected argument 'is_virtual' to be a bool")
        pulumi.set(__self__, "is_virtual", is_virtual)
        if keep_instance_name and not isinstance(keep_instance_name, bool):
            raise TypeError("Expected argument 'keep_instance_name' to be a bool")
        pulumi.set(__self__, "keep_instance_name", keep_instance_name)
        if kubernetes_config and not isinstance(kubernetes_config, dict):
            raise TypeError("Expected argument 'kubernetes_config' to be a dict")
        pulumi.set(__self__, "kubernetes_config", kubernetes_config)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if node_id and not isinstance(node_id, str):
            raise TypeError("Expected argument 'node_id' to be a str")
        pulumi.set(__self__, "node_id", node_id)
        if node_pool_id and not isinstance(node_pool_id, str):
            raise TypeError("Expected argument 'node_pool_id' to be a str")
        pulumi.set(__self__, "node_pool_id", node_pool_id)
        if roles and not isinstance(roles, list):
            raise TypeError("Expected argument 'roles' to be a list")
        pulumi.set(__self__, "roles", roles)
        if status and not isinstance(status, dict):
            raise TypeError("Expected argument 'status' to be a dict")
        pulumi.set(__self__, "status", status)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="additionalContainerStorageEnabled")
    def additional_container_storage_enabled(self) -> builtins.bool:
        """
        选择配置节点的数据盘并格式化挂载作为容器镜像和日志的存储目录，取值：false：（默认值）关闭。默认节点池：表示不挂载数据盘。自定义节点池：使用节点池的数据盘配置进行挂载，被添加到节点池的 ECS 实例数据盘必须包含目标节点池指定了挂载的数据盘（含本地盘），且盘类型和大小完全一致。true: 开启。此时必须同时配置 ContainerStoragePath 参数。节点通过 ContainerStoragePath参数中的配置进行挂载，而忽略节点池的数据盘配置，对被添加到节点池的 ECS 实例数据盘无特殊要求。
        """
        return pulumi.get(self, "additional_container_storage_enabled")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        集群的 ID。
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="containerStoragePath")
    def container_storage_path(self) -> builtins.str:
        """
        使用该数据盘设备挂载容器和镜像存储目录/var/lib/containerd。
        仅当AdditionalContainerStorageEnabled=true时有效，且不能为空。须满足以下条件，否则将初始化失败：仅支持已挂载数据盘的 ECS 实例。指定数据盘设备名时，请确保该数据盘设备存在，否则会初始化失败。指定数据盘分区或逻辑卷名时，请确保该分区或逻辑卷存在，且为 ext4 文件系统。
        """
        return pulumi.get(self, "container_storage_path")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        节点对应的 ECS 实例使用的镜像 ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="initializeScript")
    def initialize_script(self) -> builtins.str:
        """
        创建 ECS 节点并完成 Kubernetes 组件部署后执行的脚本。支持 Shell 格式，Base64 编码后长度不超过 1 KB。为空时，节点继承使用默认节点池配置的初始化脚本NodeConfig.InitializeScript。自定义填写脚本内容后，使用自定义的脚本，忽略默认节点池配置的初始化脚本。
        """
        return pulumi.get(self, "initialize_script")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        节点对应的云服务器实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="isVirtual")
    def is_virtual(self) -> builtins.bool:
        """
        是否为虚拟节点，参数值说明：false：否 true：是。
        """
        return pulumi.get(self, "is_virtual")

    @property
    @pulumi.getter(name="keepInstanceName")
    def keep_instance_name(self) -> builtins.bool:
        """
        是否保留原 ECS 实例名称，取值：false：（默认值）不保留原 ECS 实例名称，由容器服务自动为其命名。true：保留原 ECS 实例名称。
        """
        return pulumi.get(self, "keep_instance_name")

    @property
    @pulumi.getter(name="kubernetesConfig")
    def kubernetes_config(self) -> 'outputs.GetNodeKubernetesConfigResult':
        """
        节点 Kubernetes 相关配置。为空时，节点继承使用默认节点池的 Kubernetes 配置KubernetesConfig.Labels/Taints/Cordon。自定义填写配置后，使用自定义配置内容，忽略默认节点池的 Kubernetes 配置。
        """
        return pulumi.get(self, "kubernetes_config")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        节点名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> builtins.str:
        """
        节点 ID。
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter(name="nodePoolId")
    def node_pool_id(self) -> builtins.str:
        """
        节点池 ID。不传入参数值：表示将已有 ECS 实例添加到默认节点池。传入参数值：表示将已有 ECS 实例添加到自定义节点池。
        """
        return pulumi.get(self, "node_pool_id")

    @property
    @pulumi.getter
    def roles(self) -> Sequence[builtins.str]:
        """
        节点角色，参数值说明：Worker：Worker节点。
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter
    def status(self) -> 'outputs.GetNodeStatusResult':
        """
        节点状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        可用区 ID。
        """
        return pulumi.get(self, "zone_id")


class AwaitableGetNodeResult(GetNodeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNodeResult(
            additional_container_storage_enabled=self.additional_container_storage_enabled,
            cluster_id=self.cluster_id,
            container_storage_path=self.container_storage_path,
            created_time=self.created_time,
            id=self.id,
            image_id=self.image_id,
            initialize_script=self.initialize_script,
            instance_id=self.instance_id,
            is_virtual=self.is_virtual,
            keep_instance_name=self.keep_instance_name,
            kubernetes_config=self.kubernetes_config,
            name=self.name,
            node_id=self.node_id,
            node_pool_id=self.node_pool_id,
            roles=self.roles,
            status=self.status,
            updated_time=self.updated_time,
            zone_id=self.zone_id)


def get_node(id: Optional[builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNodeResult:
    """
    Data Source schema for Byteplus::VKE::Node


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vke/getNode:getNode', __args__, opts=opts, typ=GetNodeResult).value

    return AwaitableGetNodeResult(
        additional_container_storage_enabled=pulumi.get(__ret__, 'additional_container_storage_enabled'),
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        container_storage_path=pulumi.get(__ret__, 'container_storage_path'),
        created_time=pulumi.get(__ret__, 'created_time'),
        id=pulumi.get(__ret__, 'id'),
        image_id=pulumi.get(__ret__, 'image_id'),
        initialize_script=pulumi.get(__ret__, 'initialize_script'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        is_virtual=pulumi.get(__ret__, 'is_virtual'),
        keep_instance_name=pulumi.get(__ret__, 'keep_instance_name'),
        kubernetes_config=pulumi.get(__ret__, 'kubernetes_config'),
        name=pulumi.get(__ret__, 'name'),
        node_id=pulumi.get(__ret__, 'node_id'),
        node_pool_id=pulumi.get(__ret__, 'node_pool_id'),
        roles=pulumi.get(__ret__, 'roles'),
        status=pulumi.get(__ret__, 'status'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_node_output(id: Optional[pulumi.Input[builtins.str]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNodeResult]:
    """
    Data Source schema for Byteplus::VKE::Node


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vke/getNode:getNode', __args__, opts=opts, typ=GetNodeResult)
    return __ret__.apply(lambda __response__: GetNodeResult(
        additional_container_storage_enabled=pulumi.get(__response__, 'additional_container_storage_enabled'),
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        container_storage_path=pulumi.get(__response__, 'container_storage_path'),
        created_time=pulumi.get(__response__, 'created_time'),
        id=pulumi.get(__response__, 'id'),
        image_id=pulumi.get(__response__, 'image_id'),
        initialize_script=pulumi.get(__response__, 'initialize_script'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        is_virtual=pulumi.get(__response__, 'is_virtual'),
        keep_instance_name=pulumi.get(__response__, 'keep_instance_name'),
        kubernetes_config=pulumi.get(__response__, 'kubernetes_config'),
        name=pulumi.get(__response__, 'name'),
        node_id=pulumi.get(__response__, 'node_id'),
        node_pool_id=pulumi.get(__response__, 'node_pool_id'),
        roles=pulumi.get(__response__, 'roles'),
        status=pulumi.get(__response__, 'status'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        zone_id=pulumi.get(__response__, 'zone_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GroupMember',
    'PermissionSetPermissionPolicy',
    'GetGroupMemberResult',
    'GetPermissionSetPermissionPolicyResult',
]

@pulumi.output_type
class GroupMember(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "userId":
            suggest = "user_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GroupMember. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GroupMember.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GroupMember.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 user_id: Optional[builtins.str] = None):
        """
        :param builtins.str user_id: 用户id。
        """
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[builtins.str]:
        """
        用户id。
        """
        return pulumi.get(self, "user_id")


@pulumi.output_type
class PermissionSetPermissionPolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "permissionPolicyDocument":
            suggest = "permission_policy_document"
        elif key == "permissionPolicyName":
            suggest = "permission_policy_name"
        elif key == "permissionPolicyType":
            suggest = "permission_policy_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PermissionSetPermissionPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PermissionSetPermissionPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PermissionSetPermissionPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 permission_policy_document: Optional[builtins.str] = None,
                 permission_policy_name: Optional[builtins.str] = None,
                 permission_policy_type: Optional[builtins.str] = None):
        """
        :param builtins.str permission_policy_document: 策略语法内容。语法可参考 策略语法说明。
        :param builtins.str permission_policy_name: 策略名称。
        :param builtins.str permission_policy_type: 策略类型，System or Inline。
        """
        if permission_policy_document is not None:
            pulumi.set(__self__, "permission_policy_document", permission_policy_document)
        if permission_policy_name is not None:
            pulumi.set(__self__, "permission_policy_name", permission_policy_name)
        if permission_policy_type is not None:
            pulumi.set(__self__, "permission_policy_type", permission_policy_type)

    @property
    @pulumi.getter(name="permissionPolicyDocument")
    def permission_policy_document(self) -> Optional[builtins.str]:
        """
        策略语法内容。语法可参考 策略语法说明。
        """
        return pulumi.get(self, "permission_policy_document")

    @property
    @pulumi.getter(name="permissionPolicyName")
    def permission_policy_name(self) -> Optional[builtins.str]:
        """
        策略名称。
        """
        return pulumi.get(self, "permission_policy_name")

    @property
    @pulumi.getter(name="permissionPolicyType")
    def permission_policy_type(self) -> Optional[builtins.str]:
        """
        策略类型，System or Inline。
        """
        return pulumi.get(self, "permission_policy_type")


@pulumi.output_type
class GetGroupMemberResult(dict):
    def __init__(__self__, *,
                 description: builtins.str,
                 display_name: builtins.str,
                 email: builtins.str,
                 identity_type: builtins.str,
                 join_time: builtins.str,
                 phone: builtins.str,
                 source: builtins.str,
                 user_id: builtins.str,
                 user_name: builtins.str):
        """
        :param builtins.str description: 用户描述信息
        :param builtins.str display_name: 用户显示名称。
        :param builtins.str email: 用户邮箱。
        :param builtins.str identity_type: 用户身份类型。
        :param builtins.str join_time: 用户加入用户组的时间。
        :param builtins.str phone: 用户手机号。
        :param builtins.str source: 用户来源。
        :param builtins.str user_id: 用户id。
        :param builtins.str user_name: 用户名。
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "identity_type", identity_type)
        pulumi.set(__self__, "join_time", join_time)
        pulumi.set(__self__, "phone", phone)
        pulumi.set(__self__, "source", source)
        pulumi.set(__self__, "user_id", user_id)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        用户描述信息
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        用户显示名称。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        """
        用户邮箱。
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="identityType")
    def identity_type(self) -> builtins.str:
        """
        用户身份类型。
        """
        return pulumi.get(self, "identity_type")

    @property
    @pulumi.getter(name="joinTime")
    def join_time(self) -> builtins.str:
        """
        用户加入用户组的时间。
        """
        return pulumi.get(self, "join_time")

    @property
    @pulumi.getter
    def phone(self) -> builtins.str:
        """
        用户手机号。
        """
        return pulumi.get(self, "phone")

    @property
    @pulumi.getter
    def source(self) -> builtins.str:
        """
        用户来源。
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.str:
        """
        用户id。
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        用户名。
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class GetPermissionSetPermissionPolicyResult(dict):
    def __init__(__self__, *,
                 created_time: builtins.str,
                 permission_policy_document: builtins.str,
                 permission_policy_name: builtins.str,
                 permission_policy_type: builtins.str):
        """
        :param builtins.str created_time: 策略创建时间。
        :param builtins.str permission_policy_document: 策略语法内容。语法可参考 策略语法说明。
        :param builtins.str permission_policy_name: 策略名称。
        :param builtins.str permission_policy_type: 策略类型，System or Inline。
        """
        pulumi.set(__self__, "created_time", created_time)
        pulumi.set(__self__, "permission_policy_document", permission_policy_document)
        pulumi.set(__self__, "permission_policy_name", permission_policy_name)
        pulumi.set(__self__, "permission_policy_type", permission_policy_type)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        策略创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="permissionPolicyDocument")
    def permission_policy_document(self) -> builtins.str:
        """
        策略语法内容。语法可参考 策略语法说明。
        """
        return pulumi.get(self, "permission_policy_document")

    @property
    @pulumi.getter(name="permissionPolicyName")
    def permission_policy_name(self) -> builtins.str:
        """
        策略名称。
        """
        return pulumi.get(self, "permission_policy_name")

    @property
    @pulumi.getter(name="permissionPolicyType")
    def permission_policy_type(self) -> builtins.str:
        """
        策略类型，System or Inline。
        """
        return pulumi.get(self, "permission_policy_type")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetLaunchTemplateResult',
    'AwaitableGetLaunchTemplateResult',
    'get_launch_template',
    'get_launch_template_output',
]

@pulumi.output_type
class GetLaunchTemplateResult:
    """
    A collection of values returned by getLaunchTemplate.
    """
    def __init__(__self__, created_at=None, default_version_number=None, id=None, latest_version_number=None, launch_template_id=None, launch_template_name=None, launch_template_project_name=None, launch_template_tags=None, launch_template_version=None, updated_at=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if default_version_number and not isinstance(default_version_number, int):
            raise TypeError("Expected argument 'default_version_number' to be a int")
        pulumi.set(__self__, "default_version_number", default_version_number)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if latest_version_number and not isinstance(latest_version_number, int):
            raise TypeError("Expected argument 'latest_version_number' to be a int")
        pulumi.set(__self__, "latest_version_number", latest_version_number)
        if launch_template_id and not isinstance(launch_template_id, str):
            raise TypeError("Expected argument 'launch_template_id' to be a str")
        pulumi.set(__self__, "launch_template_id", launch_template_id)
        if launch_template_name and not isinstance(launch_template_name, str):
            raise TypeError("Expected argument 'launch_template_name' to be a str")
        pulumi.set(__self__, "launch_template_name", launch_template_name)
        if launch_template_project_name and not isinstance(launch_template_project_name, str):
            raise TypeError("Expected argument 'launch_template_project_name' to be a str")
        pulumi.set(__self__, "launch_template_project_name", launch_template_project_name)
        if launch_template_tags and not isinstance(launch_template_tags, list):
            raise TypeError("Expected argument 'launch_template_tags' to be a list")
        pulumi.set(__self__, "launch_template_tags", launch_template_tags)
        if launch_template_version and not isinstance(launch_template_version, dict):
            raise TypeError("Expected argument 'launch_template_version' to be a dict")
        pulumi.set(__self__, "launch_template_version", launch_template_version)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        实例启动模板的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="defaultVersionNumber")
    def default_version_number(self) -> builtins.int:
        """
        实例启动模板的默认版本号。
        """
        return pulumi.get(self, "default_version_number")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="latestVersionNumber")
    def latest_version_number(self) -> builtins.int:
        """
        实例启动模的最新版本号。
        """
        return pulumi.get(self, "latest_version_number")

    @property
    @pulumi.getter(name="launchTemplateId")
    def launch_template_id(self) -> builtins.str:
        """
        实例启动模板 ID。
        """
        return pulumi.get(self, "launch_template_id")

    @property
    @pulumi.getter(name="launchTemplateName")
    def launch_template_name(self) -> builtins.str:
        """
        实例启动模板名称。
        """
        return pulumi.get(self, "launch_template_name")

    @property
    @pulumi.getter(name="launchTemplateProjectName")
    def launch_template_project_name(self) -> builtins.str:
        """
        实例启动模版所属项目。
        """
        return pulumi.get(self, "launch_template_project_name")

    @property
    @pulumi.getter(name="launchTemplateTags")
    def launch_template_tags(self) -> Sequence['outputs.GetLaunchTemplateLaunchTemplateTagResult']:
        """
        实例启动模版的标签信息。
        """
        return pulumi.get(self, "launch_template_tags")

    @property
    @pulumi.getter(name="launchTemplateVersion")
    def launch_template_version(self) -> 'outputs.GetLaunchTemplateLaunchTemplateVersionResult':
        """
        实例启动模板版本信息。
        """
        return pulumi.get(self, "launch_template_version")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        实例启动模板的更新时间。
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetLaunchTemplateResult(GetLaunchTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLaunchTemplateResult(
            created_at=self.created_at,
            default_version_number=self.default_version_number,
            id=self.id,
            latest_version_number=self.latest_version_number,
            launch_template_id=self.launch_template_id,
            launch_template_name=self.launch_template_name,
            launch_template_project_name=self.launch_template_project_name,
            launch_template_tags=self.launch_template_tags,
            launch_template_version=self.launch_template_version,
            updated_at=self.updated_at)


def get_launch_template(id: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLaunchTemplateResult:
    """
    Data Source schema for Byteplus::ECS::Launchtemplate


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:ecs/getLaunchTemplate:getLaunchTemplate', __args__, opts=opts, typ=GetLaunchTemplateResult).value

    return AwaitableGetLaunchTemplateResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        default_version_number=pulumi.get(__ret__, 'default_version_number'),
        id=pulumi.get(__ret__, 'id'),
        latest_version_number=pulumi.get(__ret__, 'latest_version_number'),
        launch_template_id=pulumi.get(__ret__, 'launch_template_id'),
        launch_template_name=pulumi.get(__ret__, 'launch_template_name'),
        launch_template_project_name=pulumi.get(__ret__, 'launch_template_project_name'),
        launch_template_tags=pulumi.get(__ret__, 'launch_template_tags'),
        launch_template_version=pulumi.get(__ret__, 'launch_template_version'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_launch_template_output(id: Optional[pulumi.Input[builtins.str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLaunchTemplateResult]:
    """
    Data Source schema for Byteplus::ECS::Launchtemplate


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:ecs/getLaunchTemplate:getLaunchTemplate', __args__, opts=opts, typ=GetLaunchTemplateResult)
    return __ret__.apply(lambda __response__: GetLaunchTemplateResult(
        created_at=pulumi.get(__response__, 'created_at'),
        default_version_number=pulumi.get(__response__, 'default_version_number'),
        id=pulumi.get(__response__, 'id'),
        latest_version_number=pulumi.get(__response__, 'latest_version_number'),
        launch_template_id=pulumi.get(__response__, 'launch_template_id'),
        launch_template_name=pulumi.get(__response__, 'launch_template_name'),
        launch_template_project_name=pulumi.get(__response__, 'launch_template_project_name'),
        launch_template_tags=pulumi.get(__response__, 'launch_template_tags'),
        launch_template_version=pulumi.get(__response__, 'launch_template_version'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetInstancePluginResult',
    'AwaitableGetInstancePluginResult',
    'get_instance_plugin',
    'get_instance_plugin_output',
]

@pulumi.output_type
class GetInstancePluginResult:
    """
    A collection of values returned by getInstancePlugin.
    """
    def __init__(__self__, description=None, disable_prompt=None, enable_prompt=None, enabled=None, id=None, instance_id=None, need_reboot_on_change=None, plugin_name=None, port=None, version=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if disable_prompt and not isinstance(disable_prompt, str):
            raise TypeError("Expected argument 'disable_prompt' to be a str")
        pulumi.set(__self__, "disable_prompt", disable_prompt)
        if enable_prompt and not isinstance(enable_prompt, str):
            raise TypeError("Expected argument 'enable_prompt' to be a str")
        pulumi.set(__self__, "enable_prompt", enable_prompt)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if need_reboot_on_change and not isinstance(need_reboot_on_change, bool):
            raise TypeError("Expected argument 'need_reboot_on_change' to be a bool")
        pulumi.set(__self__, "need_reboot_on_change", need_reboot_on_change)
        if plugin_name and not isinstance(plugin_name, str):
            raise TypeError("Expected argument 'plugin_name' to be a str")
        pulumi.set(__self__, "plugin_name", plugin_name)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        插件描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="disablePrompt")
    def disable_prompt(self) -> builtins.str:
        """
        关闭此插件的注意事项说明。
        """
        return pulumi.get(self, "disable_prompt")

    @property
    @pulumi.getter(name="enablePrompt")
    def enable_prompt(self) -> builtins.str:
        """
        开启此插件的注意事项说明。
        """
        return pulumi.get(self, "enable_prompt")

    @property
    @pulumi.getter
    def enabled(self) -> builtins.bool:
        """
        是否已开启插件。true：插件已开启。false：插件已关闭。
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="needRebootOnChange")
    def need_reboot_on_change(self) -> builtins.bool:
        """
        开启或关闭插件是否会引发 RabbitMQ 实例重启。true：会重启实例。false：不会重启实例。
        """
        return pulumi.get(self, "need_reboot_on_change")

    @property
    @pulumi.getter(name="pluginName")
    def plugin_name(self) -> builtins.str:
        """
        插件名称。
        """
        return pulumi.get(self, "plugin_name")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        插件监听的端口。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def version(self) -> builtins.str:
        """
        插件版本。
        """
        return pulumi.get(self, "version")


class AwaitableGetInstancePluginResult(GetInstancePluginResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstancePluginResult(
            description=self.description,
            disable_prompt=self.disable_prompt,
            enable_prompt=self.enable_prompt,
            enabled=self.enabled,
            id=self.id,
            instance_id=self.instance_id,
            need_reboot_on_change=self.need_reboot_on_change,
            plugin_name=self.plugin_name,
            port=self.port,
            version=self.version)


def get_instance_plugin(id: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstancePluginResult:
    """
    Data Source schema for Byteplus::RabbitMQ::InstancePlugin


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:rabbitmq/getInstancePlugin:getInstancePlugin', __args__, opts=opts, typ=GetInstancePluginResult).value

    return AwaitableGetInstancePluginResult(
        description=pulumi.get(__ret__, 'description'),
        disable_prompt=pulumi.get(__ret__, 'disable_prompt'),
        enable_prompt=pulumi.get(__ret__, 'enable_prompt'),
        enabled=pulumi.get(__ret__, 'enabled'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        need_reboot_on_change=pulumi.get(__ret__, 'need_reboot_on_change'),
        plugin_name=pulumi.get(__ret__, 'plugin_name'),
        port=pulumi.get(__ret__, 'port'),
        version=pulumi.get(__ret__, 'version'))
def get_instance_plugin_output(id: Optional[pulumi.Input[builtins.str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstancePluginResult]:
    """
    Data Source schema for Byteplus::RabbitMQ::InstancePlugin


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:rabbitmq/getInstancePlugin:getInstancePlugin', __args__, opts=opts, typ=GetInstancePluginResult)
    return __ret__.apply(lambda __response__: GetInstancePluginResult(
        description=pulumi.get(__response__, 'description'),
        disable_prompt=pulumi.get(__response__, 'disable_prompt'),
        enable_prompt=pulumi.get(__response__, 'enable_prompt'),
        enabled=pulumi.get(__response__, 'enabled'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        need_reboot_on_change=pulumi.get(__response__, 'need_reboot_on_change'),
        plugin_name=pulumi.get(__response__, 'plugin_name'),
        port=pulumi.get(__response__, 'port'),
        version=pulumi.get(__response__, 'version')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AccountSecureContactInfoArgs',
    'AccountSecureContactInfoArgsDict',
    'AccountTagArgs',
    'AccountTagArgsDict',
]

MYPY = False

if not MYPY:
    class AccountSecureContactInfoArgsDict(TypedDict):
        email: NotRequired[pulumi.Input[builtins.str]]
        """
        安全邮箱。
        """
        email_verified: NotRequired[pulumi.Input[builtins.int]]
        """
        安全邮箱是否验证，1: 未验证，2: 已验证。
        """
        new_email: NotRequired[pulumi.Input[builtins.str]]
        """
        变更中的新邮箱。
        """
        new_phone: NotRequired[pulumi.Input[builtins.str]]
        """
        变更中的新手机号。
        """
        phone: NotRequired[pulumi.Input[builtins.str]]
        """
        安全手机号。
        """
        phone_verified: NotRequired[pulumi.Input[builtins.int]]
        """
        安全手机号是否验证，1: 未验证，2: 已验证。
        """
elif False:
    AccountSecureContactInfoArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AccountSecureContactInfoArgs:
    def __init__(__self__, *,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 email_verified: Optional[pulumi.Input[builtins.int]] = None,
                 new_email: Optional[pulumi.Input[builtins.str]] = None,
                 new_phone: Optional[pulumi.Input[builtins.str]] = None,
                 phone: Optional[pulumi.Input[builtins.str]] = None,
                 phone_verified: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.str] email: 安全邮箱。
        :param pulumi.Input[builtins.int] email_verified: 安全邮箱是否验证，1: 未验证，2: 已验证。
        :param pulumi.Input[builtins.str] new_email: 变更中的新邮箱。
        :param pulumi.Input[builtins.str] new_phone: 变更中的新手机号。
        :param pulumi.Input[builtins.str] phone: 安全手机号。
        :param pulumi.Input[builtins.int] phone_verified: 安全手机号是否验证，1: 未验证，2: 已验证。
        """
        if email is not None:
            pulumi.set(__self__, "email", email)
        if email_verified is not None:
            pulumi.set(__self__, "email_verified", email_verified)
        if new_email is not None:
            pulumi.set(__self__, "new_email", new_email)
        if new_phone is not None:
            pulumi.set(__self__, "new_phone", new_phone)
        if phone is not None:
            pulumi.set(__self__, "phone", phone)
        if phone_verified is not None:
            pulumi.set(__self__, "phone_verified", phone_verified)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全邮箱。
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="emailVerified")
    def email_verified(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        安全邮箱是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "email_verified")

    @email_verified.setter
    def email_verified(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "email_verified", value)

    @property
    @pulumi.getter(name="newEmail")
    def new_email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        变更中的新邮箱。
        """
        return pulumi.get(self, "new_email")

    @new_email.setter
    def new_email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "new_email", value)

    @property
    @pulumi.getter(name="newPhone")
    def new_phone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        变更中的新手机号。
        """
        return pulumi.get(self, "new_phone")

    @new_phone.setter
    def new_phone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "new_phone", value)

    @property
    @pulumi.getter
    def phone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全手机号。
        """
        return pulumi.get(self, "phone")

    @phone.setter
    def phone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "phone", value)

    @property
    @pulumi.getter(name="phoneVerified")
    def phone_verified(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        安全手机号是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "phone_verified")

    @phone_verified.setter
    def phone_verified(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "phone_verified", value)


if not MYPY:
    class AccountTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    AccountTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AccountTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .command import *
from .deployment_set import *
from .get_command import *
from .get_commands import *
from .get_deployment_set import *
from .get_deployment_sets import *
from .get_image import *
from .get_images import *
from .get_instance import *
from .get_instances import *
from .get_invocation import *
from .get_invocations import *
from .get_keypair import *
from .get_keypairs import *
from .get_launch_template import *
from .get_launch_template_version import *
from .get_launch_template_versions import *
from .get_launch_templates import *
from .image import *
from .instance import *
from .invocation import *
from .keypair import *
from .launch_template import *
from .launch_template_version import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetGroupResult',
    'AwaitableGetGroupResult',
    'get_group',
    'get_group_output',
]

@pulumi.output_type
class GetGroupResult:
    """
    A collection of values returned by getGroup.
    """
    def __init__(__self__, created_time=None, description=None, display_name=None, group_id=None, group_name=None, id=None, join_type=None, members=None, source=None, updated_time=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if group_name and not isinstance(group_name, str):
            raise TypeError("Expected argument 'group_name' to be a str")
        pulumi.set(__self__, "group_name", group_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if join_type and not isinstance(join_type, str):
            raise TypeError("Expected argument 'join_type' to be a str")
        pulumi.set(__self__, "join_type", join_type)
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        pulumi.set(__self__, "members", members)
        if source and not isinstance(source, str):
            raise TypeError("Expected argument 'source' to be a str")
        pulumi.set(__self__, "source", source)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        显示名。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> builtins.str:
        """
        用户组id。
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> builtins.str:
        """
        用户组名称。
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="joinType")
    def join_type(self) -> builtins.str:
        """
        用户组类型。
        """
        return pulumi.get(self, "join_type")

    @property
    @pulumi.getter
    def members(self) -> Sequence['outputs.GetGroupMemberResult']:
        """
        用户组成员列表
        """
        return pulumi.get(self, "members")

    @property
    @pulumi.getter
    def source(self) -> builtins.str:
        """
        用户组来源。
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetGroupResult(GetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupResult(
            created_time=self.created_time,
            description=self.description,
            display_name=self.display_name,
            group_id=self.group_id,
            group_name=self.group_name,
            id=self.id,
            join_type=self.join_type,
            members=self.members,
            source=self.source,
            updated_time=self.updated_time)


def get_group(id: Optional[builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupResult:
    """
    Data Source schema for Byteplus::CloudIdentity::Group


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:cloudidentity/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult).value

    return AwaitableGetGroupResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        group_id=pulumi.get(__ret__, 'group_id'),
        group_name=pulumi.get(__ret__, 'group_name'),
        id=pulumi.get(__ret__, 'id'),
        join_type=pulumi.get(__ret__, 'join_type'),
        members=pulumi.get(__ret__, 'members'),
        source=pulumi.get(__ret__, 'source'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_group_output(id: Optional[pulumi.Input[builtins.str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupResult]:
    """
    Data Source schema for Byteplus::CloudIdentity::Group


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:cloudidentity/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult)
    return __ret__.apply(lambda __response__: GetGroupResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        display_name=pulumi.get(__response__, 'display_name'),
        group_id=pulumi.get(__response__, 'group_id'),
        group_name=pulumi.get(__response__, 'group_name'),
        id=pulumi.get(__response__, 'id'),
        join_type=pulumi.get(__response__, 'join_type'),
        members=pulumi.get(__response__, 'members'),
        source=pulumi.get(__response__, 'source'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCustomerGatewayResult',
    'AwaitableGetCustomerGatewayResult',
    'get_customer_gateway',
    'get_customer_gateway_output',
]

@pulumi.output_type
class GetCustomerGatewayResult:
    """
    A collection of values returned by getCustomerGateway.
    """
    def __init__(__self__, account_id=None, asn=None, connection_count=None, created_time=None, customer_gateway_id=None, customer_gateway_name=None, description=None, id=None, ip_address=None, ip_version=None, project_name=None, status=None, tags=None, updated_time=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if asn and not isinstance(asn, int):
            raise TypeError("Expected argument 'asn' to be a int")
        pulumi.set(__self__, "asn", asn)
        if connection_count and not isinstance(connection_count, int):
            raise TypeError("Expected argument 'connection_count' to be a int")
        pulumi.set(__self__, "connection_count", connection_count)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if customer_gateway_id and not isinstance(customer_gateway_id, str):
            raise TypeError("Expected argument 'customer_gateway_id' to be a str")
        pulumi.set(__self__, "customer_gateway_id", customer_gateway_id)
        if customer_gateway_name and not isinstance(customer_gateway_name, str):
            raise TypeError("Expected argument 'customer_gateway_name' to be a str")
        pulumi.set(__self__, "customer_gateway_name", customer_gateway_name)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_address and not isinstance(ip_address, str):
            raise TypeError("Expected argument 'ip_address' to be a str")
        pulumi.set(__self__, "ip_address", ip_address)
        if ip_version and not isinstance(ip_version, str):
            raise TypeError("Expected argument 'ip_version' to be a str")
        pulumi.set(__self__, "ip_version", ip_version)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        用户网关所属账户的ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def asn(self) -> builtins.int:
        """
        用户网关的ASN（Autonomous System Number）。如需使用BGP功能，则此参数必须填写。ASN有效范围1～4294967295（137718 、150436、65533除外）。
        """
        return pulumi.get(self, "asn")

    @property
    @pulumi.getter(name="connectionCount")
    def connection_count(self) -> builtins.int:
        """
        用户网关关联的IPsec连接的数量。
        """
        return pulumi.get(self, "connection_count")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建用户网关的时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customerGatewayId")
    def customer_gateway_id(self) -> builtins.str:
        """
        网关ID。
        """
        return pulumi.get(self, "customer_gateway_id")

    @property
    @pulumi.getter(name="customerGatewayName")
    def customer_gateway_name(self) -> builtins.str:
        """
        用户网关的名称。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认为用户网关的ID。
        """
        return pulumi.get(self, "customer_gateway_name")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        用户网关的描述信息。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、空格（ ）、下划线（_）、中划线（-）、等号（=）、英文逗号（,）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> builtins.str:
        """
        对端本地数据中心网关的静态公网IP地址或其他VPC的VPN网关出口IP地址。若对端为非固定静态公网IP，此处需传入0.0.0.0。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> builtins.str:
        """
        VPN网关的IP地址协议类型，取值如下：ipv4 （默认值）ipv6
        """
        return pulumi.get(self, "ip_version")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        用户网关所属的项目。不填默认为default，即创建的资源属于default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        用户网关的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetCustomerGatewayTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新用户网关的时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetCustomerGatewayResult(GetCustomerGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCustomerGatewayResult(
            account_id=self.account_id,
            asn=self.asn,
            connection_count=self.connection_count,
            created_time=self.created_time,
            customer_gateway_id=self.customer_gateway_id,
            customer_gateway_name=self.customer_gateway_name,
            description=self.description,
            id=self.id,
            ip_address=self.ip_address,
            ip_version=self.ip_version,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time)


def get_customer_gateway(id: Optional[builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCustomerGatewayResult:
    """
    Data Source schema for Byteplus::VPN::CustomerGateway


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpn/getCustomerGateway:getCustomerGateway', __args__, opts=opts, typ=GetCustomerGatewayResult).value

    return AwaitableGetCustomerGatewayResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        asn=pulumi.get(__ret__, 'asn'),
        connection_count=pulumi.get(__ret__, 'connection_count'),
        created_time=pulumi.get(__ret__, 'created_time'),
        customer_gateway_id=pulumi.get(__ret__, 'customer_gateway_id'),
        customer_gateway_name=pulumi.get(__ret__, 'customer_gateway_name'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        ip_address=pulumi.get(__ret__, 'ip_address'),
        ip_version=pulumi.get(__ret__, 'ip_version'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_customer_gateway_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCustomerGatewayResult]:
    """
    Data Source schema for Byteplus::VPN::CustomerGateway


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpn/getCustomerGateway:getCustomerGateway', __args__, opts=opts, typ=GetCustomerGatewayResult)
    return __ret__.apply(lambda __response__: GetCustomerGatewayResult(
        account_id=pulumi.get(__response__, 'account_id'),
        asn=pulumi.get(__response__, 'asn'),
        connection_count=pulumi.get(__response__, 'connection_count'),
        created_time=pulumi.get(__response__, 'created_time'),
        customer_gateway_id=pulumi.get(__response__, 'customer_gateway_id'),
        customer_gateway_name=pulumi.get(__response__, 'customer_gateway_name'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        ip_address=pulumi.get(__response__, 'ip_address'),
        ip_version=pulumi.get(__response__, 'ip_version'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time')))
